@@ -24,6 +24,8 @@ class DeviceDcElwa(ModbusRtuDevice):
     _serial = None
     _irerror = False
     _errorcode = 0
+    _oldacdaywh = None
+    _oldacdaywhlog = None
 
     def __init__(self, serial, unitId):
         super().__init__(unitId)
@@ -57,7 +59,7 @@ class DeviceDcElwa(ModbusRtuDevice):
         self._channels["dc_current"] = ChannelConfig([1013], "NUMBER", 0, datasettype="avg")
         self._channels["dc_power"] = ChannelConfig([1014], "NUMBER", 0, datasettype="sum")
         self._channels["dc_day_wh"] = ChannelConfig([1015], "NUMBER", 0, datasettype="avg")
-        self._channels["dc_total_kwh"] = ChannelConfig([1016], "NUMBER", 0, datasettype="avg")
+        self._channels["dc_total_kwh"] = ChannelConfig([1016], "NUMBER", 0.001, datasettype="avg")
         self._channels["ac_day_wh"] = ChannelConfig([1017], "NUMBER", 0, datasettype="avg")
         self._channels["minutes_from_noon"] = ChannelConfig([1018], "NUMBER", 0, datasettype="avg")
         self._channels["minutes_since_dusk"] = ChannelConfig([1019], "NUMBER", 0, datasettype="avg")
@@ -81,14 +83,24 @@ class DeviceDcElwa(ModbusRtuDevice):
         acRelayState = self.getchannelvalue("ac_relay_state", True)
         dcPower = self.getchannelvalue("dc_power", True)
         operationMode = self.getchannelvalue("operation_mode", True)
+        acdaywh = self.getchannelvalue("ac_day_wh", True)
 
         if operationMode == 3 or operationMode == 5 or operationMode == 6 or operationMode == 7 or operationMode == 8 or operationMode == 9 or operationMode == 10 or operationMode == 11 or operationMode == 12 or operationMode == 13 or operationMode == 14 or operationMode == 15 or operationMode == 16 or operationMode == 20 or operationMode == 21 or operationMode == 135:
             acHeating = True
         else:
             acHeating = False
 
+        if self._oldacdaywh != None:
+            if self._oldacdaywh != acdaywh:
+                acchanged = True
+            else:
+                acchanged = False
+        else:
+            self._oldacdaywh = acdaywh
+            acchanged = False
+
         if acRelayState != None:
-            if acHeating == True and acRelayState == 1:
+            if acHeating == True and acRelayState == 1 and acchanged == True:
                 boostpower = 750
             else:
                 boostpower = 0
@@ -156,8 +168,22 @@ class DeviceDcElwa(ModbusRtuDevice):
 
     def getlogdata(self, time = None):
         acRelayState = self.getlogvalue("ac_relay_state")
+        acdaywh = self.getlogvalue("ac_day_wh")
+
+        if self._oldacdaywhlog != None:
+            if self._oldacdaywhlog != acdaywh:
+                acchanged = True
+            else:
+                acchanged = False
+        else:
+            self._oldacdaywhlog = acdaywh
+            acchanged = False
+
         if acRelayState != None:
-            boostpower = int(round(acRelayState*750))
+            if acchanged == False:
+                boostpower = 0
+            else:
+                boostpower = int(round(acRelayState*self._deviceBoostpower))
         else:
             boostpower = None
         
