@@ -23,6 +23,8 @@ class ElwaSc20(SerialDevice):
     _serial = None
     _devicesubtype = "ELWA-USB"
     _deviceBoostpower = 750
+    _oldacdaywh = None
+    _oldacdaywhlog = None
 
     def __init__(self, serialnumber):
 
@@ -70,8 +72,8 @@ class ElwaSc20(SerialDevice):
         self._channels["dc_current"] = ChannelConfig([15], "NUMBER", 0, registertype="serial")
         self._channels["dc_power"] = ChannelConfig([16], "NUMBER", 0, registertype="serial", datasettype="sum")
         self._channels["dc_day_wh"] = ChannelConfig([17], "NUMBER", 0, registertype="serial")
-        self._channels["dc_total_kwh"] = ChannelConfig([18], "NUMBER", 0, registertype="serial")
-        self._channels["ac_day_wh"] = ChannelConfig([19], "NUMBER", 0, registertype="serial")
+        self._channels["dc_total_kwh"] = ChannelConfig([18], "NUMBER", 0.001, registertype="serial")
+        self._channels["ac_day_wh"] = ChannelConfig([19], "NUMBER", 0, registertype="serial", datasettype="avg")
         self._channels["internal_control_value_1"] = ChannelConfig([20], "NUMBER", 0, registertype="serial")
         self._channels["internal_control_value_2"] = ChannelConfig([21], "NUMBER", 0, registertype="serial")
         self._channels["internal_control_value_3"] = ChannelConfig([22], "NUMBER", 0, registertype="serial")
@@ -124,16 +126,26 @@ class ElwaSc20(SerialDevice):
 
     def getdata(self):
         acRelayState = self.getchannelvalue("ac_relay_state", True)
-        dcPower = self.getchannelvalue("dc_power", True, 10)
+        dcPower = self.getchannelvalue("dc_power", True)
         operationMode = self.getchannelvalue("operation_mode", True)
+        acdaywh = self.getchannelvalue("ac_day_wh", True)
 
         if operationMode == 3 or operationMode == 5 or operationMode == 6 or operationMode == 7 or operationMode == 8 or operationMode == 9 or operationMode == 10 or operationMode == 11 or operationMode == 12 or operationMode == 13 or operationMode == 14 or operationMode == 15 or operationMode == 16 or operationMode == 20 or operationMode == 21 or operationMode == 135:
             acHeating = True
         else:
             acHeating = False
 
+        if self._oldacdaywh != None:
+            if self._oldacdaywh != acdaywh:
+                acchanged = True
+            else:
+                acchanged = False
+        else:
+            self._oldacdaywh = acdaywh
+            acchanged = False
+
         if acRelayState != None:
-            if acHeating == True and acRelayState == 1:
+            if acHeating == True and acRelayState == 1 and acchanged == True:
                 boostpower = self._deviceBoostpower
             else:
                 boostpower = 0
@@ -170,11 +182,11 @@ class ElwaSc20(SerialDevice):
             "tempchip": self.getchannelvalue("tempchip", True),
             "iso_voltage": self.getchannelvalue("iso_voltage", True),
             "dc_voltage": self.getchannelvalue("dc_voltage", True, 10),
-            "dc_current": self.getchannelvalue("dc_current", True, 10),
+            "dc_current": self.getchannelvalue("dc_current", True, 1000),
             "boostpower": boostpower,
             "dc_day_wh": self.getchannelvalue("dc_day_wh", True),
             "dc_total_kwh": self.getchannelvalue("dc_total_kwh", True),
-            "ac_day_wh": self.getchannelvalue("ac_day_wh", True),
+            "ac_day_wh": acdaywh,
             "ac_boost_mode": self.getchannelvalue("ac_boost_mode", True),
             "m1sum": dcPower,
             "m0sum": meter,
@@ -191,8 +203,22 @@ class ElwaSc20(SerialDevice):
 
     def getlogdata(self, time = None):
         acRelayState = self.getlogvalue("ac_relay_state")
+        acdaywh = self.getlogvalue("ac_day_wh")
+
+        if self._oldacdaywhlog != None:
+            if self._oldacdaywhlog != acdaywh:
+                acchanged = True
+            else:
+                acchanged = False
+        else:
+            self._oldacdaywhlog = acdaywh
+            acchanged = False
+
         if acRelayState != None:
-            boostpower = int(round(acRelayState*self._deviceBoostpower))
+            if acchanged == False:
+                boostpower = 0
+            else:
+                boostpower = int(round(acRelayState*self._deviceBoostpower))
         else:
             boostpower = None
         
